@@ -9,10 +9,13 @@ from ramalama.common import available
 from ramalama.layered_config import LayeredMixin, deep_merge
 from ramalama.toml_parser import TOMLParser
 
+PathStr = str
 DEFAULT_PORT_RANGE: tuple[int, int] = (8080, 8090)
 DEFAULT_PORT: int = DEFAULT_PORT_RANGE[0]
 DEFAULT_IMAGE = "quay.io/ramalama/ramalama"
-SUPPORTED_ENGINES = Literal["podman", "docker"] | os.PathLike[str]
+SUPPORTED_ENGINES = Literal["podman", "docker"] | PathStr
+SUPPORTED_RUNTIMES = Literal["llama.cpp", "vllm", "mlx"]
+COLOR_OPTIONS = Literal["auto", "always", "never"]
 
 
 def get_default_engine() -> SUPPORTED_ENGINES | None:
@@ -38,9 +41,9 @@ def coerce_to_bool(value: Any) -> bool:
         return value
     elif isinstance(value, str):
         val = value.strip().lower()
-        if val in {"true", "1", "yes", "y"}:
+        if val in {"on", "true", "1", "yes", "y"}:
             return True
-        elif val in {"false", "0", "no", "n"}:
+        elif val in {"off", "false", "0", "no", "n"}:
             return False
     raise ValueError(f"Cannot coerce {value!r} to bool")
 
@@ -64,7 +67,7 @@ class RamalamaSettings:
 class BaseConfig:
     container: bool = None  # type: ignore
     image: str = None  # type: ignore
-    carimage: str = "registry.access.redhat.com/ubi9-micro:latest"
+    carimage: str = "registry.access.redhat.com/ubi10-micro:latest"
     ctx_size: int = 2048
     engine: SUPPORTED_ENGINES | None = field(default_factory=get_default_engine)
     env: list[str] = field(default_factory=list)
@@ -84,16 +87,17 @@ class BaseConfig:
     keep_groups: bool = False
     ngl: int = -1
     threads: int = -1
-    nocontainer: bool = False
     port: str = str(DEFAULT_PORT)
     pull: str = "newer"
-    runtime: str = "llama.cpp"
+    rag_format: Literal["qdrant", "json", "markdown"] = "qdrant"
+    runtime: SUPPORTED_RUNTIMES = "llama.cpp"
     store: str = field(default_factory=get_default_store)
     temp: str = "0.8"
     transport: str = "ollama"
     ocr: bool = False
     default_image: str = DEFAULT_IMAGE
     user: UserConfig = field(default_factory=UserConfig)
+    selinux: bool = False
     settings: RamalamaSettings = field(default_factory=RamalamaSettings)
 
     def __post_init__(self):
@@ -179,7 +183,7 @@ def load_env_config(env: Mapping[str, str] | None = None) -> dict[str, Any]:
     if 'images' in config:
         config['images'] = json.loads(config['images'])
 
-    for key in ['ocr', 'nocontainer', 'keep_groups', 'container']:
+    for key in ['ocr', 'keep_groups', 'container']:
         if key in config:
             config[key] = coerce_to_bool(config[key])
 
