@@ -1,5 +1,4 @@
 import copy
-import re
 from typing import Callable, Tuple, Union
 from urllib.parse import urlparse
 
@@ -7,7 +6,7 @@ from ramalama.arg_types import StoreArgs
 from ramalama.common import rm_until_substring
 from ramalama.config import CONFIG
 from ramalama.huggingface import Huggingface
-from ramalama.model import MODEL_TYPES, SPLIT_MODEL_RE, is_split_file_model
+from ramalama.model import MODEL_TYPES
 from ramalama.modelscope import ModelScope
 from ramalama.oci import OCI
 from ramalama.ollama import Ollama
@@ -21,7 +20,6 @@ class ModelFactory:
         args: StoreArgs,
         transport: str = "ollama",
         ignore_stderr: bool = False,
-        no_children: bool = False,
     ):
         self.model = model
         self.store_path = args.store
@@ -40,25 +38,6 @@ class ModelFactory:
             dm_args = copy.deepcopy(args)
             dm_args.model_draft = None
             self.draft_model = ModelFactory(args.model_draft, dm_args, ignore_stderr=True).create()
-        if (not no_children) and is_split_file_model(model):
-            sm_args = copy.deepcopy(args)
-            sm_args.model_draft = None
-            if is_split_file_model(model):
-                match = re.match(SPLIT_MODEL_RE, model)
-                path_part = match[1]
-                filename_base = match[2]
-                total_parts = int(match[3])
-                # the model will be nr=1 (first) the child will be the higher numbers
-                self.split_model = {}
-
-                self.mnt_path = f"{filename_base}-00001-of-{total_parts:05d}.gguf"
-                for i in range(total_parts - 1):
-                    i_off = i + 2
-                    src_file = f"{path_part}/{filename_base}-{i_off:05d}-of-{total_parts:05d}.gguf"
-                    dst_file = f"{filename_base}-{i_off:05d}-of-{total_parts:05d}.gguf"
-                    self.split_model[dst_file] = ModelFactory(
-                        src_file, sm_args, ignore_stderr=True, no_children=True
-                    ).create()
 
     def detect_model_model_type(
         self,
@@ -137,13 +116,10 @@ class ModelFactory:
     def create_url(self) -> URL:
         model = URL(self.pruned_model, self.store_path, urlparse(self.model).scheme)
         model.draft_model = self.draft_model
-        if getattr(self, 'split_model', None):
-            model.split_model = self.split_model
-            model.mnt_path = self.mnt_path
         return model
 
 
-def New(name, args, transport: str = None) -> ModelFactory:
+def New(name, args, transport: str = None) -> Union[Huggingface | ModelScope | Ollama | OCI | URL]:
     if transport is None:
         transport = CONFIG.transport
     return ModelFactory(name, args, transport=transport).create()
