@@ -144,11 +144,11 @@ class Ollama(Model):
 
     def pull(self, args):
         name, tag, _ = self.extract_model_identifiers()
-        hash, cached_files, all = self.model_store.get_cached_files(tag)
+        _, cached_files, all = self.model_store.get_cached_files(tag)
         if all:
             if not args.quiet:
                 perror(f"Using cached ollama://{name}:{tag} ...")
-            return self.model_store.get_snapshot_file_path(hash, name)
+            return
 
         ollama_repo = OllamaRepository(self.model_store.model_name)
         manifest = ollama_repo.fetch_manifest(tag)
@@ -168,5 +168,3 @@ class Ollama(Model):
                 perror(f"Using cached ollama://{name}{tag} ...")
             snapshot_model_path = self.model_store.get_snapshot_file_path(model_hash, self.model_store.model_name)
             os.symlink(ollama_cache_path, snapshot_model_path)
-
-        return self.model_store.get_snapshot_file_path(model_hash, self.model_store.model_name)
